# coding: utf-8

"""
    hrm-api

    Hiring Manager can view all the pending tasks and evaluate the interview if any pending interviews.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class JobDetailsOnet(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'onet_code': 'str',
        'score': 'str',
        'onet_title': 'str'
    }

    attribute_map = {
        'onet_code': 'onet_code',
        'score': 'score',
        'onet_title': 'onet_title'
    }

    def __init__(self, onet_code=None, score=None, onet_title=None):  # noqa: E501
        """JobDetailsOnet - a model defined in Swagger"""  # noqa: E501
        self._onet_code = None
        self._score = None
        self._onet_title = None
        self.discriminator = None
        if onet_code is not None:
            self.onet_code = onet_code
        if score is not None:
            self.score = score
        if onet_title is not None:
            self.onet_title = onet_title

    @property
    def onet_code(self):
        """Gets the onet_code of this JobDetailsOnet.  # noqa: E501

        The onet code.  # noqa: E501

        :return: The onet_code of this JobDetailsOnet.  # noqa: E501
        :rtype: str
        """
        return self._onet_code

    @onet_code.setter
    def onet_code(self, onet_code):
        """Sets the onet_code of this JobDetailsOnet.

        The onet code.  # noqa: E501

        :param onet_code: The onet_code of this JobDetailsOnet.  # noqa: E501
        :type: str
        """

        self._onet_code = onet_code

    @property
    def score(self):
        """Gets the score of this JobDetailsOnet.  # noqa: E501

        The score.  # noqa: E501

        :return: The score of this JobDetailsOnet.  # noqa: E501
        :rtype: str
        """
        return self._score

    @score.setter
    def score(self, score):
        """Sets the score of this JobDetailsOnet.

        The score.  # noqa: E501

        :param score: The score of this JobDetailsOnet.  # noqa: E501
        :type: str
        """

        self._score = score

    @property
    def onet_title(self):
        """Gets the onet_title of this JobDetailsOnet.  # noqa: E501

        The onet title.  # noqa: E501

        :return: The onet_title of this JobDetailsOnet.  # noqa: E501
        :rtype: str
        """
        return self._onet_title

    @onet_title.setter
    def onet_title(self, onet_title):
        """Sets the onet_title of this JobDetailsOnet.

        The onet title.  # noqa: E501

        :param onet_title: The onet_title of this JobDetailsOnet.  # noqa: E501
        :type: str
        """

        self._onet_title = onet_title

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(JobDetailsOnet, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, JobDetailsOnet):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    resume-parser-api

    The Resume Parser extracts important information of a candidate such as candidate's name, contact information, email id, education, work experience, and skills, etc. from the resume using Deep learning models.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class ResumeResponseDataResumedataSkilltaxonomy(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'skillname': 'str',
        'lastused': 'str',
        'monthsused': 'str',
        'availability': 'str'
    }

    attribute_map = {
        'skillname': 'skillname',
        'lastused': 'lastused',
        'monthsused': 'monthsused',
        'availability': 'availability'
    }

    def __init__(self, skillname=None, lastused=None, monthsused=None, availability=None):  # noqa: E501
        """ResumeResponseDataResumedataSkilltaxonomy - a model defined in Swagger"""  # noqa: E501
        self._skillname = None
        self._lastused = None
        self._monthsused = None
        self._availability = None
        self.discriminator = None
        if skillname is not None:
            self.skillname = skillname
        if lastused is not None:
            self.lastused = lastused
        if monthsused is not None:
            self.monthsused = monthsused
        if availability is not None:
            self.availability = availability

    @property
    def skillname(self):
        """Gets the skillname of this ResumeResponseDataResumedataSkilltaxonomy.  # noqa: E501

        Skill name.  # noqa: E501

        :return: The skillname of this ResumeResponseDataResumedataSkilltaxonomy.  # noqa: E501
        :rtype: str
        """
        return self._skillname

    @skillname.setter
    def skillname(self, skillname):
        """Sets the skillname of this ResumeResponseDataResumedataSkilltaxonomy.

        Skill name.  # noqa: E501

        :param skillname: The skillname of this ResumeResponseDataResumedataSkilltaxonomy.  # noqa: E501
        :type: str
        """

        self._skillname = skillname

    @property
    def lastused(self):
        """Gets the lastused of this ResumeResponseDataResumedataSkilltaxonomy.  # noqa: E501

        Last used.  # noqa: E501

        :return: The lastused of this ResumeResponseDataResumedataSkilltaxonomy.  # noqa: E501
        :rtype: str
        """
        return self._lastused

    @lastused.setter
    def lastused(self, lastused):
        """Sets the lastused of this ResumeResponseDataResumedataSkilltaxonomy.

        Last used.  # noqa: E501

        :param lastused: The lastused of this ResumeResponseDataResumedataSkilltaxonomy.  # noqa: E501
        :type: str
        """

        self._lastused = lastused

    @property
    def monthsused(self):
        """Gets the monthsused of this ResumeResponseDataResumedataSkilltaxonomy.  # noqa: E501

        Months used.  # noqa: E501

        :return: The monthsused of this ResumeResponseDataResumedataSkilltaxonomy.  # noqa: E501
        :rtype: str
        """
        return self._monthsused

    @monthsused.setter
    def monthsused(self, monthsused):
        """Sets the monthsused of this ResumeResponseDataResumedataSkilltaxonomy.

        Months used.  # noqa: E501

        :param monthsused: The monthsused of this ResumeResponseDataResumedataSkilltaxonomy.  # noqa: E501
        :type: str
        """

        self._monthsused = monthsused

    @property
    def availability(self):
        """Gets the availability of this ResumeResponseDataResumedataSkilltaxonomy.  # noqa: E501

        Availability.  # noqa: E501

        :return: The availability of this ResumeResponseDataResumedataSkilltaxonomy.  # noqa: E501
        :rtype: str
        """
        return self._availability

    @availability.setter
    def availability(self, availability):
        """Sets the availability of this ResumeResponseDataResumedataSkilltaxonomy.

        Availability.  # noqa: E501

        :param availability: The availability of this ResumeResponseDataResumedataSkilltaxonomy.  # noqa: E501
        :type: str
        """

        self._availability = availability

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ResumeResponseDataResumedataSkilltaxonomy, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResumeResponseDataResumedataSkilltaxonomy):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    applicants-api

    This API collection enables seamless operations by facilitating the retrieval of essential applicant details, updating and managing hiring statuses for candidates, assigning multiple candidates as leads for specific job roles, and obtaining detailed activity logs associated with applicants.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class AttachmentDataAttachments(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'attachment_id': 'str',
        'attachment_name': 'str',
        'attachment_type': 'str'
    }

    attribute_map = {
        'attachment_id': 'attachmentId',
        'attachment_name': 'attachmentName',
        'attachment_type': 'attachmentType'
    }

    def __init__(self, attachment_id=None, attachment_name=None, attachment_type=None):  # noqa: E501
        """AttachmentDataAttachments - a model defined in Swagger"""  # noqa: E501
        self._attachment_id = None
        self._attachment_name = None
        self._attachment_type = None
        self.discriminator = None
        if attachment_id is not None:
            self.attachment_id = attachment_id
        if attachment_name is not None:
            self.attachment_name = attachment_name
        if attachment_type is not None:
            self.attachment_type = attachment_type

    @property
    def attachment_id(self):
        """Gets the attachment_id of this AttachmentDataAttachments.  # noqa: E501

        Unique identifier for the attachment.  # noqa: E501

        :return: The attachment_id of this AttachmentDataAttachments.  # noqa: E501
        :rtype: str
        """
        return self._attachment_id

    @attachment_id.setter
    def attachment_id(self, attachment_id):
        """Sets the attachment_id of this AttachmentDataAttachments.

        Unique identifier for the attachment.  # noqa: E501

        :param attachment_id: The attachment_id of this AttachmentDataAttachments.  # noqa: E501
        :type: str
        """

        self._attachment_id = attachment_id

    @property
    def attachment_name(self):
        """Gets the attachment_name of this AttachmentDataAttachments.  # noqa: E501

        Name of the attachment.  # noqa: E501

        :return: The attachment_name of this AttachmentDataAttachments.  # noqa: E501
        :rtype: str
        """
        return self._attachment_name

    @attachment_name.setter
    def attachment_name(self, attachment_name):
        """Sets the attachment_name of this AttachmentDataAttachments.

        Name of the attachment.  # noqa: E501

        :param attachment_name: The attachment_name of this AttachmentDataAttachments.  # noqa: E501
        :type: str
        """

        self._attachment_name = attachment_name

    @property
    def attachment_type(self):
        """Gets the attachment_type of this AttachmentDataAttachments.  # noqa: E501

        Type of the attachment.  # noqa: E501

        :return: The attachment_type of this AttachmentDataAttachments.  # noqa: E501
        :rtype: str
        """
        return self._attachment_type

    @attachment_type.setter
    def attachment_type(self, attachment_type):
        """Sets the attachment_type of this AttachmentDataAttachments.

        Type of the attachment.  # noqa: E501

        :param attachment_type: The attachment_type of this AttachmentDataAttachments.  # noqa: E501
        :type: str
        """

        self._attachment_type = attachment_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AttachmentDataAttachments, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AttachmentDataAttachments):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    applicants-api

    This API collection enables seamless operations by facilitating the retrieval of essential applicant details, updating and managing hiring statuses for candidates, assigning multiple candidates as leads for specific job roles, and obtaining detailed activity logs associated with applicants.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class HiringStatusDataApplicationsClose(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'hiring_status': 'HiringStatusDataApplicationsHiringStatus',
        'job_category': 'str',
        'job_id': 'str',
        'job_title': 'str',
        'user_id': 'str'
    }

    attribute_map = {
        'hiring_status': 'hiringStatus',
        'job_category': 'jobCategory',
        'job_id': 'jobId',
        'job_title': 'jobTitle',
        'user_id': 'userId'
    }

    def __init__(self, hiring_status=None, job_category=None, job_id=None, job_title=None, user_id=None):  # noqa: E501
        """HiringStatusDataApplicationsClose - a model defined in Swagger"""  # noqa: E501
        self._hiring_status = None
        self._job_category = None
        self._job_id = None
        self._job_title = None
        self._user_id = None
        self.discriminator = None
        if hiring_status is not None:
            self.hiring_status = hiring_status
        if job_category is not None:
            self.job_category = job_category
        if job_id is not None:
            self.job_id = job_id
        if job_title is not None:
            self.job_title = job_title
        if user_id is not None:
            self.user_id = user_id

    @property
    def hiring_status(self):
        """Gets the hiring_status of this HiringStatusDataApplicationsClose.  # noqa: E501


        :return: The hiring_status of this HiringStatusDataApplicationsClose.  # noqa: E501
        :rtype: HiringStatusDataApplicationsHiringStatus
        """
        return self._hiring_status

    @hiring_status.setter
    def hiring_status(self, hiring_status):
        """Sets the hiring_status of this HiringStatusDataApplicationsClose.


        :param hiring_status: The hiring_status of this HiringStatusDataApplicationsClose.  # noqa: E501
        :type: HiringStatusDataApplicationsHiringStatus
        """

        self._hiring_status = hiring_status

    @property
    def job_category(self):
        """Gets the job_category of this HiringStatusDataApplicationsClose.  # noqa: E501

        Category of the job associated with the application.  # noqa: E501

        :return: The job_category of this HiringStatusDataApplicationsClose.  # noqa: E501
        :rtype: str
        """
        return self._job_category

    @job_category.setter
    def job_category(self, job_category):
        """Sets the job_category of this HiringStatusDataApplicationsClose.

        Category of the job associated with the application.  # noqa: E501

        :param job_category: The job_category of this HiringStatusDataApplicationsClose.  # noqa: E501
        :type: str
        """

        self._job_category = job_category

    @property
    def job_id(self):
        """Gets the job_id of this HiringStatusDataApplicationsClose.  # noqa: E501

        ID of the job associated with the application.  # noqa: E501

        :return: The job_id of this HiringStatusDataApplicationsClose.  # noqa: E501
        :rtype: str
        """
        return self._job_id

    @job_id.setter
    def job_id(self, job_id):
        """Sets the job_id of this HiringStatusDataApplicationsClose.

        ID of the job associated with the application.  # noqa: E501

        :param job_id: The job_id of this HiringStatusDataApplicationsClose.  # noqa: E501
        :type: str
        """

        self._job_id = job_id

    @property
    def job_title(self):
        """Gets the job_title of this HiringStatusDataApplicationsClose.  # noqa: E501

        Title of the job associated with the application.  # noqa: E501

        :return: The job_title of this HiringStatusDataApplicationsClose.  # noqa: E501
        :rtype: str
        """
        return self._job_title

    @job_title.setter
    def job_title(self, job_title):
        """Sets the job_title of this HiringStatusDataApplicationsClose.

        Title of the job associated with the application.  # noqa: E501

        :param job_title: The job_title of this HiringStatusDataApplicationsClose.  # noqa: E501
        :type: str
        """

        self._job_title = job_title

    @property
    def user_id(self):
        """Gets the user_id of this HiringStatusDataApplicationsClose.  # noqa: E501

        ID of the user associated with the application.  # noqa: E501

        :return: The user_id of this HiringStatusDataApplicationsClose.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this HiringStatusDataApplicationsClose.

        ID of the user associated with the application.  # noqa: E501

        :param user_id: The user_id of this HiringStatusDataApplicationsClose.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(HiringStatusDataApplicationsClose, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HiringStatusDataApplicationsClose):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    employees-api

    The employee profile APIs are used to create, access, update and delete employee profile and preferences.  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@phenompeople.com
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class EmployeePreference(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'interests': 'list[str]',
        'locations': 'list[str]'
    }

    attribute_map = {
        'interests': 'interests',
        'locations': 'locations'
    }

    def __init__(self, interests=None, locations=None):  # noqa: E501
        """EmployeePreference - a model defined in Swagger"""  # noqa: E501
        self._interests = None
        self._locations = None
        self.discriminator = None
        if interests is not None:
            self.interests = interests
        if locations is not None:
            self.locations = locations

    @property
    def interests(self):
        """Gets the interests of this EmployeePreference.  # noqa: E501

        The areas in which the employee is interested.  # noqa: E501

        :return: The interests of this EmployeePreference.  # noqa: E501
        :rtype: list[str]
        """
        return self._interests

    @interests.setter
    def interests(self, interests):
        """Sets the interests of this EmployeePreference.

        The areas in which the employee is interested.  # noqa: E501

        :param interests: The interests of this EmployeePreference.  # noqa: E501
        :type: list[str]
        """

        self._interests = interests

    @property
    def locations(self):
        """Gets the locations of this EmployeePreference.  # noqa: E501

        The locations in which the employee is interested.  # noqa: E501

        :return: The locations of this EmployeePreference.  # noqa: E501
        :rtype: list[str]
        """
        return self._locations

    @locations.setter
    def locations(self, locations):
        """Sets the locations of this EmployeePreference.

        The locations in which the employee is interested.  # noqa: E501

        :param locations: The locations of this EmployeePreference.  # noqa: E501
        :type: list[str]
        """

        self._locations = locations

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(EmployeePreference, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EmployeePreference):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    employees-api-courses

    The Employee course APIs are related to the courses that an employee can use them for upskilling in an organisation.  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@phenompeople.com
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class Course(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'title': 'str',
        'image_url': 'str',
        'url': 'str',
        'category': 'str',
        'provider': 'str',
        'asset_type': 'str',
        'skills_acquired': 'list[str]'
    }

    attribute_map = {
        'id': 'id',
        'title': 'title',
        'image_url': 'imageUrl',
        'url': 'url',
        'category': 'category',
        'provider': 'provider',
        'asset_type': 'assetType',
        'skills_acquired': 'skillsAcquired'
    }

    def __init__(self, id=None, title=None, image_url=None, url=None, category=None, provider=None, asset_type=None, skills_acquired=None):  # noqa: E501
        """Course - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._title = None
        self._image_url = None
        self._url = None
        self._category = None
        self._provider = None
        self._asset_type = None
        self._skills_acquired = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if title is not None:
            self.title = title
        if image_url is not None:
            self.image_url = image_url
        if url is not None:
            self.url = url
        if category is not None:
            self.category = category
        if provider is not None:
            self.provider = provider
        if asset_type is not None:
            self.asset_type = asset_type
        if skills_acquired is not None:
            self.skills_acquired = skills_acquired

    @property
    def id(self):
        """Gets the id of this Course.  # noqa: E501

        Id - unique field to identify the Course.  # noqa: E501

        :return: The id of this Course.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Course.

        Id - unique field to identify the Course.  # noqa: E501

        :param id: The id of this Course.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def title(self):
        """Gets the title of this Course.  # noqa: E501

        Title of the Course.  # noqa: E501

        :return: The title of this Course.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this Course.

        Title of the Course.  # noqa: E501

        :param title: The title of this Course.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def image_url(self):
        """Gets the image_url of this Course.  # noqa: E501

        Image URL of the Course.  # noqa: E501

        :return: The image_url of this Course.  # noqa: E501
        :rtype: str
        """
        return self._image_url

    @image_url.setter
    def image_url(self, image_url):
        """Sets the image_url of this Course.

        Image URL of the Course.  # noqa: E501

        :param image_url: The image_url of this Course.  # noqa: E501
        :type: str
        """

        self._image_url = image_url

    @property
    def url(self):
        """Gets the url of this Course.  # noqa: E501

        URL of the Course to access.  # noqa: E501

        :return: The url of this Course.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this Course.

        URL of the Course to access.  # noqa: E501

        :param url: The url of this Course.  # noqa: E501
        :type: str
        """

        self._url = url

    @property
    def category(self):
        """Gets the category of this Course.  # noqa: E501

        Category the Course belongs to.  # noqa: E501

        :return: The category of this Course.  # noqa: E501
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this Course.

        Category the Course belongs to.  # noqa: E501

        :param category: The category of this Course.  # noqa: E501
        :type: str
        """

        self._category = category

    @property
    def provider(self):
        """Gets the provider of this Course.  # noqa: E501

        Provider the Course. Ex: Coursera.  # noqa: E501

        :return: The provider of this Course.  # noqa: E501
        :rtype: str
        """
        return self._provider

    @provider.setter
    def provider(self, provider):
        """Sets the provider of this Course.

        Provider the Course. Ex: Coursera.  # noqa: E501

        :param provider: The provider of this Course.  # noqa: E501
        :type: str
        """

        self._provider = provider

    @property
    def asset_type(self):
        """Gets the asset_type of this Course.  # noqa: E501

        AssetType of the Course.  # noqa: E501

        :return: The asset_type of this Course.  # noqa: E501
        :rtype: str
        """
        return self._asset_type

    @asset_type.setter
    def asset_type(self, asset_type):
        """Sets the asset_type of this Course.

        AssetType of the Course.  # noqa: E501

        :param asset_type: The asset_type of this Course.  # noqa: E501
        :type: str
        """

        self._asset_type = asset_type

    @property
    def skills_acquired(self):
        """Gets the skills_acquired of this Course.  # noqa: E501


        :return: The skills_acquired of this Course.  # noqa: E501
        :rtype: list[str]
        """
        return self._skills_acquired

    @skills_acquired.setter
    def skills_acquired(self, skills_acquired):
        """Sets the skills_acquired of this Course.


        :param skills_acquired: The skills_acquired of this Course.  # noqa: E501
        :type: list[str]
        """

        self._skills_acquired = skills_acquired

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Course, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Course):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

# flake8: noqa

"""
    ex-search-api

    These APIs helps in searching and providing suggestions based on keywords within employee profiles.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

from __future__ import absolute_import

# import apis into sdk package
from phenom.api.exsearch.employee_search_api import EmployeeSearchApi
from phenom.api.exsearch.mentor_api import MentorApi
# import ApiClient
from phenom.commons.api_client import ApiClient
from phenom.commons.configuration import Configuration
# import models into sdk package
from phenom.api.exsearch.models.aggregations_node import AggregationsNode
from phenom.api.exsearch.models.bad_request import BadRequest
from phenom.api.exsearch.models.common_node import CommonNode
from phenom.api.exsearch.models.employee_aggregation_request import EmployeeAggregationRequest
from phenom.api.exsearch.models.employee_aggregation_response import EmployeeAggregationResponse
from phenom.api.exsearch.models.employee_node import EmployeeNode
from phenom.api.exsearch.models.employee_search_request import EmployeeSearchRequest
from phenom.api.exsearch.models.employee_search_response import EmployeeSearchResponse
from phenom.api.exsearch.models.employee_search_response_data import EmployeeSearchResponseData
from phenom.api.exsearch.models.employee_type_ahead_request import EmployeeTypeAheadRequest
from phenom.api.exsearch.models.employee_typeahead_response import EmployeeTypeaheadResponse
from phenom.api.exsearch.models.employee_typeahead_response_data import EmployeeTypeaheadResponseData
from phenom.api.exsearch.models.error_response import ErrorResponse
from phenom.api.exsearch.models.facets_node import FacetsNode
from phenom.api.exsearch.models.filters_node import FiltersNode
from phenom.api.exsearch.models.mentor_type_ahead_request import MentorTypeAheadRequest
from phenom.api.exsearch.models.mentor_typeahead_response import MentorTypeaheadResponse
from phenom.api.exsearch.models.tab_info_node import TabInfoNode



# coding: utf-8

"""
    resume-parser-api

    The Resume Parser extracts important information of a candidate such as candidate's name, contact information, email id, education, work experience, and skills, etc. from the resume using Deep learning models.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class ResumeResponseDataResumedata(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'personname': 'ResumeResponseDataResumedataPersonname',
        'mobile': 'list[ResumeResponseDataResumedataMobile]',
        'emailaddress': 'str',
        'altemailaddress': 'str',
        'internetaddress': 'list[ResumeResponseDataResumedataInternetaddress]',
        'postaladdress': 'list[ResumeResponseDataResumedataPostaladdress]',
        'resumelanguage': 'str',
        'languageknown': 'str',
        'experiencesummary': 'ResumeResponseDataResumedataExperiencesummary',
        'filename': 'str',
        'resumetext': 'str',
        'summary': 'str',
        'resumeskills': 'str',
        'skilltaxonomy': 'list[ResumeResponseDataResumedataSkilltaxonomy]',
        'educationhistory': 'list[ResumeResponseDataResumedataEducationhistory]',
        'workhistory': 'list[ResumeResponseDataResumedataWorkhistory]'
    }

    attribute_map = {
        'personname': 'personname',
        'mobile': 'mobile',
        'emailaddress': 'emailaddress',
        'altemailaddress': 'altemailaddress',
        'internetaddress': 'internetaddress',
        'postaladdress': 'postaladdress',
        'resumelanguage': 'resumelanguage',
        'languageknown': 'languageknown',
        'experiencesummary': 'experiencesummary',
        'filename': 'filename',
        'resumetext': 'resumetext',
        'summary': 'summary',
        'resumeskills': 'resumeskills',
        'skilltaxonomy': 'skilltaxonomy',
        'educationhistory': 'educationhistory',
        'workhistory': 'workhistory'
    }

    def __init__(self, personname=None, mobile=None, emailaddress=None, altemailaddress=None, internetaddress=None, postaladdress=None, resumelanguage=None, languageknown=None, experiencesummary=None, filename=None, resumetext=None, summary=None, resumeskills=None, skilltaxonomy=None, educationhistory=None, workhistory=None):  # noqa: E501
        """ResumeResponseDataResumedata - a model defined in Swagger"""  # noqa: E501
        self._personname = None
        self._mobile = None
        self._emailaddress = None
        self._altemailaddress = None
        self._internetaddress = None
        self._postaladdress = None
        self._resumelanguage = None
        self._languageknown = None
        self._experiencesummary = None
        self._filename = None
        self._resumetext = None
        self._summary = None
        self._resumeskills = None
        self._skilltaxonomy = None
        self._educationhistory = None
        self._workhistory = None
        self.discriminator = None
        if personname is not None:
            self.personname = personname
        if mobile is not None:
            self.mobile = mobile
        if emailaddress is not None:
            self.emailaddress = emailaddress
        if altemailaddress is not None:
            self.altemailaddress = altemailaddress
        if internetaddress is not None:
            self.internetaddress = internetaddress
        if postaladdress is not None:
            self.postaladdress = postaladdress
        if resumelanguage is not None:
            self.resumelanguage = resumelanguage
        if languageknown is not None:
            self.languageknown = languageknown
        if experiencesummary is not None:
            self.experiencesummary = experiencesummary
        if filename is not None:
            self.filename = filename
        if resumetext is not None:
            self.resumetext = resumetext
        if summary is not None:
            self.summary = summary
        if resumeskills is not None:
            self.resumeskills = resumeskills
        if skilltaxonomy is not None:
            self.skilltaxonomy = skilltaxonomy
        if educationhistory is not None:
            self.educationhistory = educationhistory
        if workhistory is not None:
            self.workhistory = workhistory

    @property
    def personname(self):
        """Gets the personname of this ResumeResponseDataResumedata.  # noqa: E501


        :return: The personname of this ResumeResponseDataResumedata.  # noqa: E501
        :rtype: ResumeResponseDataResumedataPersonname
        """
        return self._personname

    @personname.setter
    def personname(self, personname):
        """Sets the personname of this ResumeResponseDataResumedata.


        :param personname: The personname of this ResumeResponseDataResumedata.  # noqa: E501
        :type: ResumeResponseDataResumedataPersonname
        """

        self._personname = personname

    @property
    def mobile(self):
        """Gets the mobile of this ResumeResponseDataResumedata.  # noqa: E501

        Candidate contact details.  # noqa: E501

        :return: The mobile of this ResumeResponseDataResumedata.  # noqa: E501
        :rtype: list[ResumeResponseDataResumedataMobile]
        """
        return self._mobile

    @mobile.setter
    def mobile(self, mobile):
        """Sets the mobile of this ResumeResponseDataResumedata.

        Candidate contact details.  # noqa: E501

        :param mobile: The mobile of this ResumeResponseDataResumedata.  # noqa: E501
        :type: list[ResumeResponseDataResumedataMobile]
        """

        self._mobile = mobile

    @property
    def emailaddress(self):
        """Gets the emailaddress of this ResumeResponseDataResumedata.  # noqa: E501

        Email address of Candidate.  # noqa: E501

        :return: The emailaddress of this ResumeResponseDataResumedata.  # noqa: E501
        :rtype: str
        """
        return self._emailaddress

    @emailaddress.setter
    def emailaddress(self, emailaddress):
        """Sets the emailaddress of this ResumeResponseDataResumedata.

        Email address of Candidate.  # noqa: E501

        :param emailaddress: The emailaddress of this ResumeResponseDataResumedata.  # noqa: E501
        :type: str
        """

        self._emailaddress = emailaddress

    @property
    def altemailaddress(self):
        """Gets the altemailaddress of this ResumeResponseDataResumedata.  # noqa: E501

        Alternate Email other than primary mail.  # noqa: E501

        :return: The altemailaddress of this ResumeResponseDataResumedata.  # noqa: E501
        :rtype: str
        """
        return self._altemailaddress

    @altemailaddress.setter
    def altemailaddress(self, altemailaddress):
        """Sets the altemailaddress of this ResumeResponseDataResumedata.

        Alternate Email other than primary mail.  # noqa: E501

        :param altemailaddress: The altemailaddress of this ResumeResponseDataResumedata.  # noqa: E501
        :type: str
        """

        self._altemailaddress = altemailaddress

    @property
    def internetaddress(self):
        """Gets the internetaddress of this ResumeResponseDataResumedata.  # noqa: E501

        Candidate Internet address details.  # noqa: E501

        :return: The internetaddress of this ResumeResponseDataResumedata.  # noqa: E501
        :rtype: list[ResumeResponseDataResumedataInternetaddress]
        """
        return self._internetaddress

    @internetaddress.setter
    def internetaddress(self, internetaddress):
        """Sets the internetaddress of this ResumeResponseDataResumedata.

        Candidate Internet address details.  # noqa: E501

        :param internetaddress: The internetaddress of this ResumeResponseDataResumedata.  # noqa: E501
        :type: list[ResumeResponseDataResumedataInternetaddress]
        """

        self._internetaddress = internetaddress

    @property
    def postaladdress(self):
        """Gets the postaladdress of this ResumeResponseDataResumedata.  # noqa: E501

        Candidate postal details.  # noqa: E501

        :return: The postaladdress of this ResumeResponseDataResumedata.  # noqa: E501
        :rtype: list[ResumeResponseDataResumedataPostaladdress]
        """
        return self._postaladdress

    @postaladdress.setter
    def postaladdress(self, postaladdress):
        """Sets the postaladdress of this ResumeResponseDataResumedata.

        Candidate postal details.  # noqa: E501

        :param postaladdress: The postaladdress of this ResumeResponseDataResumedata.  # noqa: E501
        :type: list[ResumeResponseDataResumedataPostaladdress]
        """

        self._postaladdress = postaladdress

    @property
    def resumelanguage(self):
        """Gets the resumelanguage of this ResumeResponseDataResumedata.  # noqa: E501

        Language of resume content.  # noqa: E501

        :return: The resumelanguage of this ResumeResponseDataResumedata.  # noqa: E501
        :rtype: str
        """
        return self._resumelanguage

    @resumelanguage.setter
    def resumelanguage(self, resumelanguage):
        """Sets the resumelanguage of this ResumeResponseDataResumedata.

        Language of resume content.  # noqa: E501

        :param resumelanguage: The resumelanguage of this ResumeResponseDataResumedata.  # noqa: E501
        :type: str
        """

        self._resumelanguage = resumelanguage

    @property
    def languageknown(self):
        """Gets the languageknown of this ResumeResponseDataResumedata.  # noqa: E501

        Language known by candidate.  # noqa: E501

        :return: The languageknown of this ResumeResponseDataResumedata.  # noqa: E501
        :rtype: str
        """
        return self._languageknown

    @languageknown.setter
    def languageknown(self, languageknown):
        """Sets the languageknown of this ResumeResponseDataResumedata.

        Language known by candidate.  # noqa: E501

        :param languageknown: The languageknown of this ResumeResponseDataResumedata.  # noqa: E501
        :type: str
        """

        self._languageknown = languageknown

    @property
    def experiencesummary(self):
        """Gets the experiencesummary of this ResumeResponseDataResumedata.  # noqa: E501


        :return: The experiencesummary of this ResumeResponseDataResumedata.  # noqa: E501
        :rtype: ResumeResponseDataResumedataExperiencesummary
        """
        return self._experiencesummary

    @experiencesummary.setter
    def experiencesummary(self, experiencesummary):
        """Sets the experiencesummary of this ResumeResponseDataResumedata.


        :param experiencesummary: The experiencesummary of this ResumeResponseDataResumedata.  # noqa: E501
        :type: ResumeResponseDataResumedataExperiencesummary
        """

        self._experiencesummary = experiencesummary

    @property
    def filename(self):
        """Gets the filename of this ResumeResponseDataResumedata.  # noqa: E501

        Attached file name.  # noqa: E501

        :return: The filename of this ResumeResponseDataResumedata.  # noqa: E501
        :rtype: str
        """
        return self._filename

    @filename.setter
    def filename(self, filename):
        """Sets the filename of this ResumeResponseDataResumedata.

        Attached file name.  # noqa: E501

        :param filename: The filename of this ResumeResponseDataResumedata.  # noqa: E501
        :type: str
        """

        self._filename = filename

    @property
    def resumetext(self):
        """Gets the resumetext of this ResumeResponseDataResumedata.  # noqa: E501

        Resume Content.  # noqa: E501

        :return: The resumetext of this ResumeResponseDataResumedata.  # noqa: E501
        :rtype: str
        """
        return self._resumetext

    @resumetext.setter
    def resumetext(self, resumetext):
        """Sets the resumetext of this ResumeResponseDataResumedata.

        Resume Content.  # noqa: E501

        :param resumetext: The resumetext of this ResumeResponseDataResumedata.  # noqa: E501
        :type: str
        """

        self._resumetext = resumetext

    @property
    def summary(self):
        """Gets the summary of this ResumeResponseDataResumedata.  # noqa: E501

        Summary.  # noqa: E501

        :return: The summary of this ResumeResponseDataResumedata.  # noqa: E501
        :rtype: str
        """
        return self._summary

    @summary.setter
    def summary(self, summary):
        """Sets the summary of this ResumeResponseDataResumedata.

        Summary.  # noqa: E501

        :param summary: The summary of this ResumeResponseDataResumedata.  # noqa: E501
        :type: str
        """

        self._summary = summary

    @property
    def resumeskills(self):
        """Gets the resumeskills of this ResumeResponseDataResumedata.  # noqa: E501

        Resume skills.  # noqa: E501

        :return: The resumeskills of this ResumeResponseDataResumedata.  # noqa: E501
        :rtype: str
        """
        return self._resumeskills

    @resumeskills.setter
    def resumeskills(self, resumeskills):
        """Sets the resumeskills of this ResumeResponseDataResumedata.

        Resume skills.  # noqa: E501

        :param resumeskills: The resumeskills of this ResumeResponseDataResumedata.  # noqa: E501
        :type: str
        """

        self._resumeskills = resumeskills

    @property
    def skilltaxonomy(self):
        """Gets the skilltaxonomy of this ResumeResponseDataResumedata.  # noqa: E501

        Candidate skills history.  # noqa: E501

        :return: The skilltaxonomy of this ResumeResponseDataResumedata.  # noqa: E501
        :rtype: list[ResumeResponseDataResumedataSkilltaxonomy]
        """
        return self._skilltaxonomy

    @skilltaxonomy.setter
    def skilltaxonomy(self, skilltaxonomy):
        """Sets the skilltaxonomy of this ResumeResponseDataResumedata.

        Candidate skills history.  # noqa: E501

        :param skilltaxonomy: The skilltaxonomy of this ResumeResponseDataResumedata.  # noqa: E501
        :type: list[ResumeResponseDataResumedataSkilltaxonomy]
        """

        self._skilltaxonomy = skilltaxonomy

    @property
    def educationhistory(self):
        """Gets the educationhistory of this ResumeResponseDataResumedata.  # noqa: E501

        Candidate education info.  # noqa: E501

        :return: The educationhistory of this ResumeResponseDataResumedata.  # noqa: E501
        :rtype: list[ResumeResponseDataResumedataEducationhistory]
        """
        return self._educationhistory

    @educationhistory.setter
    def educationhistory(self, educationhistory):
        """Sets the educationhistory of this ResumeResponseDataResumedata.

        Candidate education info.  # noqa: E501

        :param educationhistory: The educationhistory of this ResumeResponseDataResumedata.  # noqa: E501
        :type: list[ResumeResponseDataResumedataEducationhistory]
        """

        self._educationhistory = educationhistory

    @property
    def workhistory(self):
        """Gets the workhistory of this ResumeResponseDataResumedata.  # noqa: E501

        Candidate work or experience details.  # noqa: E501

        :return: The workhistory of this ResumeResponseDataResumedata.  # noqa: E501
        :rtype: list[ResumeResponseDataResumedataWorkhistory]
        """
        return self._workhistory

    @workhistory.setter
    def workhistory(self, workhistory):
        """Sets the workhistory of this ResumeResponseDataResumedata.

        Candidate work or experience details.  # noqa: E501

        :param workhistory: The workhistory of this ResumeResponseDataResumedata.  # noqa: E501
        :type: list[ResumeResponseDataResumedataWorkhistory]
        """

        self._workhistory = workhistory

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ResumeResponseDataResumedata, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResumeResponseDataResumedata):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    projects-api

    These APIs allows you to create workflow statuses, which are then assigned to workflows. These workflows, containing multiple statuses, are subsequently linked to projects. Additionally, candidates are associated with projects, defining the path they are meant to follow within the established workflows.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class GetProjectsResponseUpdatedRecruiterInfo(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'recruiter_user_id': 'str',
        'recruiter_name': 'str',
        'recruiter_email': 'str'
    }

    attribute_map = {
        'recruiter_user_id': 'recruiterUserId',
        'recruiter_name': 'recruiterName',
        'recruiter_email': 'recruiterEmail'
    }

    def __init__(self, recruiter_user_id=None, recruiter_name=None, recruiter_email=None):  # noqa: E501
        """GetProjectsResponseUpdatedRecruiterInfo - a model defined in Swagger"""  # noqa: E501
        self._recruiter_user_id = None
        self._recruiter_name = None
        self._recruiter_email = None
        self.discriminator = None
        if recruiter_user_id is not None:
            self.recruiter_user_id = recruiter_user_id
        if recruiter_name is not None:
            self.recruiter_name = recruiter_name
        if recruiter_email is not None:
            self.recruiter_email = recruiter_email

    @property
    def recruiter_user_id(self):
        """Gets the recruiter_user_id of this GetProjectsResponseUpdatedRecruiterInfo.  # noqa: E501

        The unique identifier for the recruiter who last updated the project.  # noqa: E501

        :return: The recruiter_user_id of this GetProjectsResponseUpdatedRecruiterInfo.  # noqa: E501
        :rtype: str
        """
        return self._recruiter_user_id

    @recruiter_user_id.setter
    def recruiter_user_id(self, recruiter_user_id):
        """Sets the recruiter_user_id of this GetProjectsResponseUpdatedRecruiterInfo.

        The unique identifier for the recruiter who last updated the project.  # noqa: E501

        :param recruiter_user_id: The recruiter_user_id of this GetProjectsResponseUpdatedRecruiterInfo.  # noqa: E501
        :type: str
        """

        self._recruiter_user_id = recruiter_user_id

    @property
    def recruiter_name(self):
        """Gets the recruiter_name of this GetProjectsResponseUpdatedRecruiterInfo.  # noqa: E501

        The name of the recruiter who last updated the project.  # noqa: E501

        :return: The recruiter_name of this GetProjectsResponseUpdatedRecruiterInfo.  # noqa: E501
        :rtype: str
        """
        return self._recruiter_name

    @recruiter_name.setter
    def recruiter_name(self, recruiter_name):
        """Sets the recruiter_name of this GetProjectsResponseUpdatedRecruiterInfo.

        The name of the recruiter who last updated the project.  # noqa: E501

        :param recruiter_name: The recruiter_name of this GetProjectsResponseUpdatedRecruiterInfo.  # noqa: E501
        :type: str
        """

        self._recruiter_name = recruiter_name

    @property
    def recruiter_email(self):
        """Gets the recruiter_email of this GetProjectsResponseUpdatedRecruiterInfo.  # noqa: E501

        The email of the recruiter who last updated the project.  # noqa: E501

        :return: The recruiter_email of this GetProjectsResponseUpdatedRecruiterInfo.  # noqa: E501
        :rtype: str
        """
        return self._recruiter_email

    @recruiter_email.setter
    def recruiter_email(self, recruiter_email):
        """Sets the recruiter_email of this GetProjectsResponseUpdatedRecruiterInfo.

        The email of the recruiter who last updated the project.  # noqa: E501

        :param recruiter_email: The recruiter_email of this GetProjectsResponseUpdatedRecruiterInfo.  # noqa: E501
        :type: str
        """

        self._recruiter_email = recruiter_email

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetProjectsResponseUpdatedRecruiterInfo, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetProjectsResponseUpdatedRecruiterInfo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    servicehub-public-api

    Public APIs for managing user data.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class SearchResponse(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'data': 'list[SearchResponseData]',
        'status': 'bool',
        'error_code': 'str',
        'error_desc': 'str',
        'warning_desc': 'str',
        '_from': 'float',
        'size': 'float',
        'total': 'float'
    }

    attribute_map = {
        'data': 'data',
        'status': 'status',
        'error_code': 'errorCode',
        'error_desc': 'errorDesc',
        'warning_desc': 'warningDesc',
        '_from': 'from',
        'size': 'size',
        'total': 'total'
    }

    def __init__(self, data=None, status=None, error_code=None, error_desc=None, warning_desc=None, _from=None, size=None, total=None):  # noqa: E501
        """SearchResponse - a model defined in Swagger"""  # noqa: E501
        self._data = None
        self._status = None
        self._error_code = None
        self._error_desc = None
        self._warning_desc = None
        self.__from = None
        self._size = None
        self._total = None
        self.discriminator = None
        if data is not None:
            self.data = data
        if status is not None:
            self.status = status
        if error_code is not None:
            self.error_code = error_code
        if error_desc is not None:
            self.error_desc = error_desc
        if warning_desc is not None:
            self.warning_desc = warning_desc
        if _from is not None:
            self._from = _from
        if size is not None:
            self.size = size
        if total is not None:
            self.total = total

    @property
    def data(self):
        """Gets the data of this SearchResponse.  # noqa: E501

        List of user data.  # noqa: E501

        :return: The data of this SearchResponse.  # noqa: E501
        :rtype: list[SearchResponseData]
        """
        return self._data

    @data.setter
    def data(self, data):
        """Sets the data of this SearchResponse.

        List of user data.  # noqa: E501

        :param data: The data of this SearchResponse.  # noqa: E501
        :type: list[SearchResponseData]
        """

        self._data = data

    @property
    def status(self):
        """Gets the status of this SearchResponse.  # noqa: E501

        Status of the search operation.  # noqa: E501

        :return: The status of this SearchResponse.  # noqa: E501
        :rtype: bool
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this SearchResponse.

        Status of the search operation.  # noqa: E501

        :param status: The status of this SearchResponse.  # noqa: E501
        :type: bool
        """

        self._status = status

    @property
    def error_code(self):
        """Gets the error_code of this SearchResponse.  # noqa: E501

        The HTTP status code.  # noqa: E501

        :return: The error_code of this SearchResponse.  # noqa: E501
        :rtype: str
        """
        return self._error_code

    @error_code.setter
    def error_code(self, error_code):
        """Sets the error_code of this SearchResponse.

        The HTTP status code.  # noqa: E501

        :param error_code: The error_code of this SearchResponse.  # noqa: E501
        :type: str
        """

        self._error_code = error_code

    @property
    def error_desc(self):
        """Gets the error_desc of this SearchResponse.  # noqa: E501

        Description of the error.  # noqa: E501

        :return: The error_desc of this SearchResponse.  # noqa: E501
        :rtype: str
        """
        return self._error_desc

    @error_desc.setter
    def error_desc(self, error_desc):
        """Sets the error_desc of this SearchResponse.

        Description of the error.  # noqa: E501

        :param error_desc: The error_desc of this SearchResponse.  # noqa: E501
        :type: str
        """

        self._error_desc = error_desc

    @property
    def warning_desc(self):
        """Gets the warning_desc of this SearchResponse.  # noqa: E501

        Description of any warnings.  # noqa: E501

        :return: The warning_desc of this SearchResponse.  # noqa: E501
        :rtype: str
        """
        return self._warning_desc

    @warning_desc.setter
    def warning_desc(self, warning_desc):
        """Sets the warning_desc of this SearchResponse.

        Description of any warnings.  # noqa: E501

        :param warning_desc: The warning_desc of this SearchResponse.  # noqa: E501
        :type: str
        """

        self._warning_desc = warning_desc

    @property
    def _from(self):
        """Gets the _from of this SearchResponse.  # noqa: E501

        Starting index of the returned results.  # noqa: E501

        :return: The _from of this SearchResponse.  # noqa: E501
        :rtype: float
        """
        return self.__from

    @_from.setter
    def _from(self, _from):
        """Sets the _from of this SearchResponse.

        Starting index of the returned results.  # noqa: E501

        :param _from: The _from of this SearchResponse.  # noqa: E501
        :type: float
        """

        self.__from = _from

    @property
    def size(self):
        """Gets the size of this SearchResponse.  # noqa: E501

        Number of results returned in the response.  # noqa: E501

        :return: The size of this SearchResponse.  # noqa: E501
        :rtype: float
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this SearchResponse.

        Number of results returned in the response.  # noqa: E501

        :param size: The size of this SearchResponse.  # noqa: E501
        :type: float
        """

        self._size = size

    @property
    def total(self):
        """Gets the total of this SearchResponse.  # noqa: E501

        Total number of results matching the search criteria.  # noqa: E501

        :return: The total of this SearchResponse.  # noqa: E501
        :rtype: float
        """
        return self._total

    @total.setter
    def total(self, total):
        """Sets the total of this SearchResponse.

        Total number of results matching the search criteria.  # noqa: E501

        :param total: The total of this SearchResponse.  # noqa: E501
        :type: float
        """

        self._total = total

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SearchResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SearchResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    hrm-api

    Hiring Manager can view all the pending tasks and evaluate the interview if any pending interviews.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class GetCandidatesRequest(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        '_from': 'float',
        'type': 'str',
        'sort_by': 'GetCandidatesRequestSortBy',
        'size': 'float',
        'status': 'str',
        'filters': 'list[GetCandidatesRequestFilters]'
    }

    attribute_map = {
        '_from': 'from',
        'type': 'type',
        'sort_by': 'sortBy',
        'size': 'size',
        'status': 'status',
        'filters': 'filters'
    }

    def __init__(self, _from=None, type=None, sort_by=None, size=None, status=None, filters=None):  # noqa: E501
        """GetCandidatesRequest - a model defined in Swagger"""  # noqa: E501
        self.__from = None
        self._type = None
        self._sort_by = None
        self._size = None
        self._status = None
        self._filters = None
        self.discriminator = None
        if _from is not None:
            self._from = _from
        if type is not None:
            self.type = type
        if sort_by is not None:
            self.sort_by = sort_by
        if size is not None:
            self.size = size
        if status is not None:
            self.status = status
        if filters is not None:
            self.filters = filters

    @property
    def _from(self):
        """Gets the _from of this GetCandidatesRequest.  # noqa: E501

        Number to fetch records from.  # noqa: E501

        :return: The _from of this GetCandidatesRequest.  # noqa: E501
        :rtype: float
        """
        return self.__from

    @_from.setter
    def _from(self, _from):
        """Sets the _from of this GetCandidatesRequest.

        Number to fetch records from.  # noqa: E501

        :param _from: The _from of this GetCandidatesRequest.  # noqa: E501
        :type: float
        """

        self.__from = _from

    @property
    def type(self):
        """Gets the type of this GetCandidatesRequest.  # noqa: E501

        List or grid view of candidates.  # noqa: E501

        :return: The type of this GetCandidatesRequest.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this GetCandidatesRequest.

        List or grid view of candidates.  # noqa: E501

        :param type: The type of this GetCandidatesRequest.  # noqa: E501
        :type: str
        """

        self._type = type

    @property
    def sort_by(self):
        """Gets the sort_by of this GetCandidatesRequest.  # noqa: E501


        :return: The sort_by of this GetCandidatesRequest.  # noqa: E501
        :rtype: GetCandidatesRequestSortBy
        """
        return self._sort_by

    @sort_by.setter
    def sort_by(self, sort_by):
        """Sets the sort_by of this GetCandidatesRequest.


        :param sort_by: The sort_by of this GetCandidatesRequest.  # noqa: E501
        :type: GetCandidatesRequestSortBy
        """

        self._sort_by = sort_by

    @property
    def size(self):
        """Gets the size of this GetCandidatesRequest.  # noqa: E501

        Number of records to return.  # noqa: E501

        :return: The size of this GetCandidatesRequest.  # noqa: E501
        :rtype: float
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this GetCandidatesRequest.

        Number of records to return.  # noqa: E501

        :param size: The size of this GetCandidatesRequest.  # noqa: E501
        :type: float
        """

        self._size = size

    @property
    def status(self):
        """Gets the status of this GetCandidatesRequest.  # noqa: E501

        Different stages in Hiring Hierarchy.  # noqa: E501

        :return: The status of this GetCandidatesRequest.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this GetCandidatesRequest.

        Different stages in Hiring Hierarchy.  # noqa: E501

        :param status: The status of this GetCandidatesRequest.  # noqa: E501
        :type: str
        """
        allowed_values = ["PROFILE_REVIEW", "READY_FOR_INTERVIEW", "EVALUATION", "REVIEW_PENDING", "EVALUATE_PENDING", "WAITING_FOR_OFFER_DECISION", "OFFER_PENDING", "OFFER_PROCEED", "HIRED", "REJECTED", "ALL"]  # noqa: E501
        if status not in allowed_values:
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def filters(self):
        """Gets the filters of this GetCandidatesRequest.  # noqa: E501

        Criteria for filtering the candidates.  # noqa: E501

        :return: The filters of this GetCandidatesRequest.  # noqa: E501
        :rtype: list[GetCandidatesRequestFilters]
        """
        return self._filters

    @filters.setter
    def filters(self, filters):
        """Sets the filters of this GetCandidatesRequest.

        Criteria for filtering the candidates.  # noqa: E501

        :param filters: The filters of this GetCandidatesRequest.  # noqa: E501
        :type: list[GetCandidatesRequestFilters]
        """

        self._filters = filters

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetCandidatesRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetCandidatesRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    evaluation-api

    Hiring Manager can view all the pending tasks and evaluate the interview if any pending interviews.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class EvaluationFormsDetailsDataEvaluationForms(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'title': 'str',
        'recommended_reasons': 'list[str]',
        'not_recommended_reasons': 'list[str]',
        'not_now_reasons': 'list[str]',
        'created_by': 'str',
        'last_modified_by': 'str',
        'last_modified_by_recruiter_user_id': 'str',
        'created_by_recruiter_user_id': 'str',
        'additional_questions': 'list[QuestionAndAnswers]',
        'is_default': 'bool',
        'created_date': 'str',
        'updated_date': 'str',
        'active': 'bool',
        'deleted': 'bool',
        'evaluation_form_id': 'str',
        'version_id': 'float'
    }

    attribute_map = {
        'id': '_id',
        'title': 'title',
        'recommended_reasons': 'recommendedReasons',
        'not_recommended_reasons': 'notRecommendedReasons',
        'not_now_reasons': 'notNowReasons',
        'created_by': 'createdBy',
        'last_modified_by': 'lastModifiedBy',
        'last_modified_by_recruiter_user_id': 'lastModifiedByRecruiterUserId',
        'created_by_recruiter_user_id': 'createdByRecruiterUserId',
        'additional_questions': 'additionalQuestions',
        'is_default': 'isDefault',
        'created_date': 'createdDate',
        'updated_date': 'updatedDate',
        'active': 'active',
        'deleted': 'deleted',
        'evaluation_form_id': 'evaluationFormId',
        'version_id': 'versionId'
    }

    def __init__(self, id=None, title=None, recommended_reasons=None, not_recommended_reasons=None, not_now_reasons=None, created_by=None, last_modified_by=None, last_modified_by_recruiter_user_id=None, created_by_recruiter_user_id=None, additional_questions=None, is_default=None, created_date=None, updated_date=None, active=None, deleted=None, evaluation_form_id=None, version_id=None):  # noqa: E501
        """EvaluationFormsDetailsDataEvaluationForms - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._title = None
        self._recommended_reasons = None
        self._not_recommended_reasons = None
        self._not_now_reasons = None
        self._created_by = None
        self._last_modified_by = None
        self._last_modified_by_recruiter_user_id = None
        self._created_by_recruiter_user_id = None
        self._additional_questions = None
        self._is_default = None
        self._created_date = None
        self._updated_date = None
        self._active = None
        self._deleted = None
        self._evaluation_form_id = None
        self._version_id = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if title is not None:
            self.title = title
        if recommended_reasons is not None:
            self.recommended_reasons = recommended_reasons
        if not_recommended_reasons is not None:
            self.not_recommended_reasons = not_recommended_reasons
        if not_now_reasons is not None:
            self.not_now_reasons = not_now_reasons
        if created_by is not None:
            self.created_by = created_by
        if last_modified_by is not None:
            self.last_modified_by = last_modified_by
        if last_modified_by_recruiter_user_id is not None:
            self.last_modified_by_recruiter_user_id = last_modified_by_recruiter_user_id
        if created_by_recruiter_user_id is not None:
            self.created_by_recruiter_user_id = created_by_recruiter_user_id
        if additional_questions is not None:
            self.additional_questions = additional_questions
        if is_default is not None:
            self.is_default = is_default
        if created_date is not None:
            self.created_date = created_date
        if updated_date is not None:
            self.updated_date = updated_date
        if active is not None:
            self.active = active
        if deleted is not None:
            self.deleted = deleted
        if evaluation_form_id is not None:
            self.evaluation_form_id = evaluation_form_id
        if version_id is not None:
            self.version_id = version_id

    @property
    def id(self):
        """Gets the id of this EvaluationFormsDetailsDataEvaluationForms.  # noqa: E501

        Database document object id.  # noqa: E501

        :return: The id of this EvaluationFormsDetailsDataEvaluationForms.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this EvaluationFormsDetailsDataEvaluationForms.

        Database document object id.  # noqa: E501

        :param id: The id of this EvaluationFormsDetailsDataEvaluationForms.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def title(self):
        """Gets the title of this EvaluationFormsDetailsDataEvaluationForms.  # noqa: E501

        Title of the evaluation form.  # noqa: E501

        :return: The title of this EvaluationFormsDetailsDataEvaluationForms.  # noqa: E501
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this EvaluationFormsDetailsDataEvaluationForms.

        Title of the evaluation form.  # noqa: E501

        :param title: The title of this EvaluationFormsDetailsDataEvaluationForms.  # noqa: E501
        :type: str
        """

        self._title = title

    @property
    def recommended_reasons(self):
        """Gets the recommended_reasons of this EvaluationFormsDetailsDataEvaluationForms.  # noqa: E501

        List of reasons for recommendation.  # noqa: E501

        :return: The recommended_reasons of this EvaluationFormsDetailsDataEvaluationForms.  # noqa: E501
        :rtype: list[str]
        """
        return self._recommended_reasons

    @recommended_reasons.setter
    def recommended_reasons(self, recommended_reasons):
        """Sets the recommended_reasons of this EvaluationFormsDetailsDataEvaluationForms.

        List of reasons for recommendation.  # noqa: E501

        :param recommended_reasons: The recommended_reasons of this EvaluationFormsDetailsDataEvaluationForms.  # noqa: E501
        :type: list[str]
        """

        self._recommended_reasons = recommended_reasons

    @property
    def not_recommended_reasons(self):
        """Gets the not_recommended_reasons of this EvaluationFormsDetailsDataEvaluationForms.  # noqa: E501

        List of reasons for non recommendation.  # noqa: E501

        :return: The not_recommended_reasons of this EvaluationFormsDetailsDataEvaluationForms.  # noqa: E501
        :rtype: list[str]
        """
        return self._not_recommended_reasons

    @not_recommended_reasons.setter
    def not_recommended_reasons(self, not_recommended_reasons):
        """Sets the not_recommended_reasons of this EvaluationFormsDetailsDataEvaluationForms.

        List of reasons for non recommendation.  # noqa: E501

        :param not_recommended_reasons: The not_recommended_reasons of this EvaluationFormsDetailsDataEvaluationForms.  # noqa: E501
        :type: list[str]
        """

        self._not_recommended_reasons = not_recommended_reasons

    @property
    def not_now_reasons(self):
        """Gets the not_now_reasons of this EvaluationFormsDetailsDataEvaluationForms.  # noqa: E501

        List of reasons for not now.  # noqa: E501

        :return: The not_now_reasons of this EvaluationFormsDetailsDataEvaluationForms.  # noqa: E501
        :rtype: list[str]
        """
        return self._not_now_reasons

    @not_now_reasons.setter
    def not_now_reasons(self, not_now_reasons):
        """Sets the not_now_reasons of this EvaluationFormsDetailsDataEvaluationForms.

        List of reasons for not now.  # noqa: E501

        :param not_now_reasons: The not_now_reasons of this EvaluationFormsDetailsDataEvaluationForms.  # noqa: E501
        :type: list[str]
        """

        self._not_now_reasons = not_now_reasons

    @property
    def created_by(self):
        """Gets the created_by of this EvaluationFormsDetailsDataEvaluationForms.  # noqa: E501

        Name of the user created evaluation form.  # noqa: E501

        :return: The created_by of this EvaluationFormsDetailsDataEvaluationForms.  # noqa: E501
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this EvaluationFormsDetailsDataEvaluationForms.

        Name of the user created evaluation form.  # noqa: E501

        :param created_by: The created_by of this EvaluationFormsDetailsDataEvaluationForms.  # noqa: E501
        :type: str
        """

        self._created_by = created_by

    @property
    def last_modified_by(self):
        """Gets the last_modified_by of this EvaluationFormsDetailsDataEvaluationForms.  # noqa: E501

        Evaluation form last modified by.  # noqa: E501

        :return: The last_modified_by of this EvaluationFormsDetailsDataEvaluationForms.  # noqa: E501
        :rtype: str
        """
        return self._last_modified_by

    @last_modified_by.setter
    def last_modified_by(self, last_modified_by):
        """Sets the last_modified_by of this EvaluationFormsDetailsDataEvaluationForms.

        Evaluation form last modified by.  # noqa: E501

        :param last_modified_by: The last_modified_by of this EvaluationFormsDetailsDataEvaluationForms.  # noqa: E501
        :type: str
        """

        self._last_modified_by = last_modified_by

    @property
    def last_modified_by_recruiter_user_id(self):
        """Gets the last_modified_by_recruiter_user_id of this EvaluationFormsDetailsDataEvaluationForms.  # noqa: E501

        Evaluation form last modified by recruiter user id.  # noqa: E501

        :return: The last_modified_by_recruiter_user_id of this EvaluationFormsDetailsDataEvaluationForms.  # noqa: E501
        :rtype: str
        """
        return self._last_modified_by_recruiter_user_id

    @last_modified_by_recruiter_user_id.setter
    def last_modified_by_recruiter_user_id(self, last_modified_by_recruiter_user_id):
        """Sets the last_modified_by_recruiter_user_id of this EvaluationFormsDetailsDataEvaluationForms.

        Evaluation form last modified by recruiter user id.  # noqa: E501

        :param last_modified_by_recruiter_user_id: The last_modified_by_recruiter_user_id of this EvaluationFormsDetailsDataEvaluationForms.  # noqa: E501
        :type: str
        """

        self._last_modified_by_recruiter_user_id = last_modified_by_recruiter_user_id

    @property
    def created_by_recruiter_user_id(self):
        """Gets the created_by_recruiter_user_id of this EvaluationFormsDetailsDataEvaluationForms.  # noqa: E501

        Recruiter user id who created evaluation form.  # noqa: E501

        :return: The created_by_recruiter_user_id of this EvaluationFormsDetailsDataEvaluationForms.  # noqa: E501
        :rtype: str
        """
        return self._created_by_recruiter_user_id

    @created_by_recruiter_user_id.setter
    def created_by_recruiter_user_id(self, created_by_recruiter_user_id):
        """Sets the created_by_recruiter_user_id of this EvaluationFormsDetailsDataEvaluationForms.

        Recruiter user id who created evaluation form.  # noqa: E501

        :param created_by_recruiter_user_id: The created_by_recruiter_user_id of this EvaluationFormsDetailsDataEvaluationForms.  # noqa: E501
        :type: str
        """

        self._created_by_recruiter_user_id = created_by_recruiter_user_id

    @property
    def additional_questions(self):
        """Gets the additional_questions of this EvaluationFormsDetailsDataEvaluationForms.  # noqa: E501

        List of additional questions.  # noqa: E501

        :return: The additional_questions of this EvaluationFormsDetailsDataEvaluationForms.  # noqa: E501
        :rtype: list[QuestionAndAnswers]
        """
        return self._additional_questions

    @additional_questions.setter
    def additional_questions(self, additional_questions):
        """Sets the additional_questions of this EvaluationFormsDetailsDataEvaluationForms.

        List of additional questions.  # noqa: E501

        :param additional_questions: The additional_questions of this EvaluationFormsDetailsDataEvaluationForms.  # noqa: E501
        :type: list[QuestionAndAnswers]
        """

        self._additional_questions = additional_questions

    @property
    def is_default(self):
        """Gets the is_default of this EvaluationFormsDetailsDataEvaluationForms.  # noqa: E501

        Is a tenant's default form (true or false).  # noqa: E501

        :return: The is_default of this EvaluationFormsDetailsDataEvaluationForms.  # noqa: E501
        :rtype: bool
        """
        return self._is_default

    @is_default.setter
    def is_default(self, is_default):
        """Sets the is_default of this EvaluationFormsDetailsDataEvaluationForms.

        Is a tenant's default form (true or false).  # noqa: E501

        :param is_default: The is_default of this EvaluationFormsDetailsDataEvaluationForms.  # noqa: E501
        :type: bool
        """

        self._is_default = is_default

    @property
    def created_date(self):
        """Gets the created_date of this EvaluationFormsDetailsDataEvaluationForms.  # noqa: E501

        Evaluation form created date.  # noqa: E501

        :return: The created_date of this EvaluationFormsDetailsDataEvaluationForms.  # noqa: E501
        :rtype: str
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """Sets the created_date of this EvaluationFormsDetailsDataEvaluationForms.

        Evaluation form created date.  # noqa: E501

        :param created_date: The created_date of this EvaluationFormsDetailsDataEvaluationForms.  # noqa: E501
        :type: str
        """

        self._created_date = created_date

    @property
    def updated_date(self):
        """Gets the updated_date of this EvaluationFormsDetailsDataEvaluationForms.  # noqa: E501

        Evaluation form latest updated date.  # noqa: E501

        :return: The updated_date of this EvaluationFormsDetailsDataEvaluationForms.  # noqa: E501
        :rtype: str
        """
        return self._updated_date

    @updated_date.setter
    def updated_date(self, updated_date):
        """Sets the updated_date of this EvaluationFormsDetailsDataEvaluationForms.

        Evaluation form latest updated date.  # noqa: E501

        :param updated_date: The updated_date of this EvaluationFormsDetailsDataEvaluationForms.  # noqa: E501
        :type: str
        """

        self._updated_date = updated_date

    @property
    def active(self):
        """Gets the active of this EvaluationFormsDetailsDataEvaluationForms.  # noqa: E501

        Is an active evaluation form (true or false).  # noqa: E501

        :return: The active of this EvaluationFormsDetailsDataEvaluationForms.  # noqa: E501
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this EvaluationFormsDetailsDataEvaluationForms.

        Is an active evaluation form (true or false).  # noqa: E501

        :param active: The active of this EvaluationFormsDetailsDataEvaluationForms.  # noqa: E501
        :type: bool
        """

        self._active = active

    @property
    def deleted(self):
        """Gets the deleted of this EvaluationFormsDetailsDataEvaluationForms.  # noqa: E501

        Is a deleted evaluation form (true or false).  # noqa: E501

        :return: The deleted of this EvaluationFormsDetailsDataEvaluationForms.  # noqa: E501
        :rtype: bool
        """
        return self._deleted

    @deleted.setter
    def deleted(self, deleted):
        """Sets the deleted of this EvaluationFormsDetailsDataEvaluationForms.

        Is a deleted evaluation form (true or false).  # noqa: E501

        :param deleted: The deleted of this EvaluationFormsDetailsDataEvaluationForms.  # noqa: E501
        :type: bool
        """

        self._deleted = deleted

    @property
    def evaluation_form_id(self):
        """Gets the evaluation_form_id of this EvaluationFormsDetailsDataEvaluationForms.  # noqa: E501

        Unique evaluation form id.  # noqa: E501

        :return: The evaluation_form_id of this EvaluationFormsDetailsDataEvaluationForms.  # noqa: E501
        :rtype: str
        """
        return self._evaluation_form_id

    @evaluation_form_id.setter
    def evaluation_form_id(self, evaluation_form_id):
        """Sets the evaluation_form_id of this EvaluationFormsDetailsDataEvaluationForms.

        Unique evaluation form id.  # noqa: E501

        :param evaluation_form_id: The evaluation_form_id of this EvaluationFormsDetailsDataEvaluationForms.  # noqa: E501
        :type: str
        """

        self._evaluation_form_id = evaluation_form_id

    @property
    def version_id(self):
        """Gets the version_id of this EvaluationFormsDetailsDataEvaluationForms.  # noqa: E501

        Version id of the evaluation form.  # noqa: E501

        :return: The version_id of this EvaluationFormsDetailsDataEvaluationForms.  # noqa: E501
        :rtype: float
        """
        return self._version_id

    @version_id.setter
    def version_id(self, version_id):
        """Sets the version_id of this EvaluationFormsDetailsDataEvaluationForms.

        Version id of the evaluation form.  # noqa: E501

        :param version_id: The version_id of this EvaluationFormsDetailsDataEvaluationForms.  # noqa: E501
        :type: float
        """

        self._version_id = version_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(EvaluationFormsDetailsDataEvaluationForms, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EvaluationFormsDetailsDataEvaluationForms):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    projects-api

    These APIs allows you to create workflow statuses, which are then assigned to workflows. These workflows, containing multiple statuses, are subsequently linked to projects. Additionally, candidates are associated with projects, defining the path they are meant to follow within the established workflows.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class BadRequestErrorErrors(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'timestamp': 'str',
        'error_api': 'str',
        'message': 'str'
    }

    attribute_map = {
        'timestamp': 'timestamp',
        'error_api': 'errorAPI',
        'message': 'message'
    }

    def __init__(self, timestamp=None, error_api=None, message=None):  # noqa: E501
        """BadRequestErrorErrors - a model defined in Swagger"""  # noqa: E501
        self._timestamp = None
        self._error_api = None
        self._message = None
        self.discriminator = None
        if timestamp is not None:
            self.timestamp = timestamp
        if error_api is not None:
            self.error_api = error_api
        if message is not None:
            self.message = message

    @property
    def timestamp(self):
        """Gets the timestamp of this BadRequestErrorErrors.  # noqa: E501

        The timestamp indicating when the error occurred.  # noqa: E501

        :return: The timestamp of this BadRequestErrorErrors.  # noqa: E501
        :rtype: str
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """Sets the timestamp of this BadRequestErrorErrors.

        The timestamp indicating when the error occurred.  # noqa: E501

        :param timestamp: The timestamp of this BadRequestErrorErrors.  # noqa: E501
        :type: str
        """

        self._timestamp = timestamp

    @property
    def error_api(self):
        """Gets the error_api of this BadRequestErrorErrors.  # noqa: E501

        The API or endpoint associated with the error.  # noqa: E501

        :return: The error_api of this BadRequestErrorErrors.  # noqa: E501
        :rtype: str
        """
        return self._error_api

    @error_api.setter
    def error_api(self, error_api):
        """Sets the error_api of this BadRequestErrorErrors.

        The API or endpoint associated with the error.  # noqa: E501

        :param error_api: The error_api of this BadRequestErrorErrors.  # noqa: E501
        :type: str
        """

        self._error_api = error_api

    @property
    def message(self):
        """Gets the message of this BadRequestErrorErrors.  # noqa: E501

        A descriptive error message.  # noqa: E501

        :return: The message of this BadRequestErrorErrors.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this BadRequestErrorErrors.

        A descriptive error message.  # noqa: E501

        :param message: The message of this BadRequestErrorErrors.  # noqa: E501
        :type: str
        """

        self._message = message

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(BadRequestErrorErrors, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BadRequestErrorErrors):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    videoplatform-api

    Interview Screening APIs allows to invite candidate to interview, evaluate and review candidates interview performances.  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@phenompeople.com
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class GetInterviewDetailsForEvaluatingResponseData(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'status': 'str',
        'video_screen_id': 'str',
        'restart_count': 'float',
        're_invite_count': 'float',
        'interview_details': 'GetInterviewDetailsForEvaluatingResponseDataInterviewDetails',
        'candidate_info': 'GetInterviewDetailsForEvaluatingResponseDataCandidateInfo',
        'questions': 'list[GetInterviewDetailsForEvaluatingResponseDataQuestions]',
        'video_deleted': 'bool',
        'transcribe_enabled': 'bool',
        'assessment_late_submitted': 'bool',
        'total_score_percentage': 'str',
        'answered_score_points': 'float',
        'max_score_points': 'float',
        'has_scored_question': 'bool'
    }

    attribute_map = {
        'status': 'status',
        'video_screen_id': 'videoScreenId',
        'restart_count': 'restartCount',
        're_invite_count': 'reInviteCount',
        'interview_details': 'interviewDetails',
        'candidate_info': 'candidateInfo',
        'questions': 'questions',
        'video_deleted': 'videoDeleted',
        'transcribe_enabled': 'transcribeEnabled',
        'assessment_late_submitted': 'assessmentLateSubmitted',
        'total_score_percentage': 'totalScorePercentage',
        'answered_score_points': 'answeredScorePoints',
        'max_score_points': 'maxScorePoints',
        'has_scored_question': 'hasScoredQuestion'
    }

    def __init__(self, status=None, video_screen_id=None, restart_count=None, re_invite_count=None, interview_details=None, candidate_info=None, questions=None, video_deleted=None, transcribe_enabled=None, assessment_late_submitted=None, total_score_percentage=None, answered_score_points=None, max_score_points=None, has_scored_question=None):  # noqa: E501
        """GetInterviewDetailsForEvaluatingResponseData - a model defined in Swagger"""  # noqa: E501
        self._status = None
        self._video_screen_id = None
        self._restart_count = None
        self._re_invite_count = None
        self._interview_details = None
        self._candidate_info = None
        self._questions = None
        self._video_deleted = None
        self._transcribe_enabled = None
        self._assessment_late_submitted = None
        self._total_score_percentage = None
        self._answered_score_points = None
        self._max_score_points = None
        self._has_scored_question = None
        self.discriminator = None
        self.status = status
        self.video_screen_id = video_screen_id
        if restart_count is not None:
            self.restart_count = restart_count
        if re_invite_count is not None:
            self.re_invite_count = re_invite_count
        self.interview_details = interview_details
        self.candidate_info = candidate_info
        self.questions = questions
        if video_deleted is not None:
            self.video_deleted = video_deleted
        self.transcribe_enabled = transcribe_enabled
        self.assessment_late_submitted = assessment_late_submitted
        self.total_score_percentage = total_score_percentage
        self.answered_score_points = answered_score_points
        self.max_score_points = max_score_points
        self.has_scored_question = has_scored_question

    @property
    def status(self):
        """Gets the status of this GetInterviewDetailsForEvaluatingResponseData.  # noqa: E501

        Success or Failure.  # noqa: E501

        :return: The status of this GetInterviewDetailsForEvaluatingResponseData.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this GetInterviewDetailsForEvaluatingResponseData.

        Success or Failure.  # noqa: E501

        :param status: The status of this GetInterviewDetailsForEvaluatingResponseData.  # noqa: E501
        :type: str
        """
        if status is None:
            raise ValueError("Invalid value for `status`, must not be `None`")  # noqa: E501

        self._status = status

    @property
    def video_screen_id(self):
        """Gets the video_screen_id of this GetInterviewDetailsForEvaluatingResponseData.  # noqa: E501

        This is the interviewId.  # noqa: E501

        :return: The video_screen_id of this GetInterviewDetailsForEvaluatingResponseData.  # noqa: E501
        :rtype: str
        """
        return self._video_screen_id

    @video_screen_id.setter
    def video_screen_id(self, video_screen_id):
        """Sets the video_screen_id of this GetInterviewDetailsForEvaluatingResponseData.

        This is the interviewId.  # noqa: E501

        :param video_screen_id: The video_screen_id of this GetInterviewDetailsForEvaluatingResponseData.  # noqa: E501
        :type: str
        """
        if video_screen_id is None:
            raise ValueError("Invalid value for `video_screen_id`, must not be `None`")  # noqa: E501

        self._video_screen_id = video_screen_id

    @property
    def restart_count(self):
        """Gets the restart_count of this GetInterviewDetailsForEvaluatingResponseData.  # noqa: E501

        This indicates how many times candidate has restarted the interview.  # noqa: E501

        :return: The restart_count of this GetInterviewDetailsForEvaluatingResponseData.  # noqa: E501
        :rtype: float
        """
        return self._restart_count

    @restart_count.setter
    def restart_count(self, restart_count):
        """Sets the restart_count of this GetInterviewDetailsForEvaluatingResponseData.

        This indicates how many times candidate has restarted the interview.  # noqa: E501

        :param restart_count: The restart_count of this GetInterviewDetailsForEvaluatingResponseData.  # noqa: E501
        :type: float
        """

        self._restart_count = restart_count

    @property
    def re_invite_count(self):
        """Gets the re_invite_count of this GetInterviewDetailsForEvaluatingResponseData.  # noqa: E501

        This indicates how many times invite has been sent to candidate.  # noqa: E501

        :return: The re_invite_count of this GetInterviewDetailsForEvaluatingResponseData.  # noqa: E501
        :rtype: float
        """
        return self._re_invite_count

    @re_invite_count.setter
    def re_invite_count(self, re_invite_count):
        """Sets the re_invite_count of this GetInterviewDetailsForEvaluatingResponseData.

        This indicates how many times invite has been sent to candidate.  # noqa: E501

        :param re_invite_count: The re_invite_count of this GetInterviewDetailsForEvaluatingResponseData.  # noqa: E501
        :type: float
        """

        self._re_invite_count = re_invite_count

    @property
    def interview_details(self):
        """Gets the interview_details of this GetInterviewDetailsForEvaluatingResponseData.  # noqa: E501


        :return: The interview_details of this GetInterviewDetailsForEvaluatingResponseData.  # noqa: E501
        :rtype: GetInterviewDetailsForEvaluatingResponseDataInterviewDetails
        """
        return self._interview_details

    @interview_details.setter
    def interview_details(self, interview_details):
        """Sets the interview_details of this GetInterviewDetailsForEvaluatingResponseData.


        :param interview_details: The interview_details of this GetInterviewDetailsForEvaluatingResponseData.  # noqa: E501
        :type: GetInterviewDetailsForEvaluatingResponseDataInterviewDetails
        """
        if interview_details is None:
            raise ValueError("Invalid value for `interview_details`, must not be `None`")  # noqa: E501

        self._interview_details = interview_details

    @property
    def candidate_info(self):
        """Gets the candidate_info of this GetInterviewDetailsForEvaluatingResponseData.  # noqa: E501


        :return: The candidate_info of this GetInterviewDetailsForEvaluatingResponseData.  # noqa: E501
        :rtype: GetInterviewDetailsForEvaluatingResponseDataCandidateInfo
        """
        return self._candidate_info

    @candidate_info.setter
    def candidate_info(self, candidate_info):
        """Sets the candidate_info of this GetInterviewDetailsForEvaluatingResponseData.


        :param candidate_info: The candidate_info of this GetInterviewDetailsForEvaluatingResponseData.  # noqa: E501
        :type: GetInterviewDetailsForEvaluatingResponseDataCandidateInfo
        """
        if candidate_info is None:
            raise ValueError("Invalid value for `candidate_info`, must not be `None`")  # noqa: E501

        self._candidate_info = candidate_info

    @property
    def questions(self):
        """Gets the questions of this GetInterviewDetailsForEvaluatingResponseData.  # noqa: E501

        This provides all questions.  # noqa: E501

        :return: The questions of this GetInterviewDetailsForEvaluatingResponseData.  # noqa: E501
        :rtype: list[GetInterviewDetailsForEvaluatingResponseDataQuestions]
        """
        return self._questions

    @questions.setter
    def questions(self, questions):
        """Sets the questions of this GetInterviewDetailsForEvaluatingResponseData.

        This provides all questions.  # noqa: E501

        :param questions: The questions of this GetInterviewDetailsForEvaluatingResponseData.  # noqa: E501
        :type: list[GetInterviewDetailsForEvaluatingResponseDataQuestions]
        """
        if questions is None:
            raise ValueError("Invalid value for `questions`, must not be `None`")  # noqa: E501

        self._questions = questions

    @property
    def video_deleted(self):
        """Gets the video_deleted of this GetInterviewDetailsForEvaluatingResponseData.  # noqa: E501

        Video deleted can be true or false.  # noqa: E501

        :return: The video_deleted of this GetInterviewDetailsForEvaluatingResponseData.  # noqa: E501
        :rtype: bool
        """
        return self._video_deleted

    @video_deleted.setter
    def video_deleted(self, video_deleted):
        """Sets the video_deleted of this GetInterviewDetailsForEvaluatingResponseData.

        Video deleted can be true or false.  # noqa: E501

        :param video_deleted: The video_deleted of this GetInterviewDetailsForEvaluatingResponseData.  # noqa: E501
        :type: bool
        """

        self._video_deleted = video_deleted

    @property
    def transcribe_enabled(self):
        """Gets the transcribe_enabled of this GetInterviewDetailsForEvaluatingResponseData.  # noqa: E501

        Transcribe enabled can be true or false.  # noqa: E501

        :return: The transcribe_enabled of this GetInterviewDetailsForEvaluatingResponseData.  # noqa: E501
        :rtype: bool
        """
        return self._transcribe_enabled

    @transcribe_enabled.setter
    def transcribe_enabled(self, transcribe_enabled):
        """Sets the transcribe_enabled of this GetInterviewDetailsForEvaluatingResponseData.

        Transcribe enabled can be true or false.  # noqa: E501

        :param transcribe_enabled: The transcribe_enabled of this GetInterviewDetailsForEvaluatingResponseData.  # noqa: E501
        :type: bool
        """
        if transcribe_enabled is None:
            raise ValueError("Invalid value for `transcribe_enabled`, must not be `None`")  # noqa: E501

        self._transcribe_enabled = transcribe_enabled

    @property
    def assessment_late_submitted(self):
        """Gets the assessment_late_submitted of this GetInterviewDetailsForEvaluatingResponseData.  # noqa: E501

        Candidate submitted assessment late can be true or false.  # noqa: E501

        :return: The assessment_late_submitted of this GetInterviewDetailsForEvaluatingResponseData.  # noqa: E501
        :rtype: bool
        """
        return self._assessment_late_submitted

    @assessment_late_submitted.setter
    def assessment_late_submitted(self, assessment_late_submitted):
        """Sets the assessment_late_submitted of this GetInterviewDetailsForEvaluatingResponseData.

        Candidate submitted assessment late can be true or false.  # noqa: E501

        :param assessment_late_submitted: The assessment_late_submitted of this GetInterviewDetailsForEvaluatingResponseData.  # noqa: E501
        :type: bool
        """
        if assessment_late_submitted is None:
            raise ValueError("Invalid value for `assessment_late_submitted`, must not be `None`")  # noqa: E501

        self._assessment_late_submitted = assessment_late_submitted

    @property
    def total_score_percentage(self):
        """Gets the total_score_percentage of this GetInterviewDetailsForEvaluatingResponseData.  # noqa: E501

        Percentage score candidate has scored when he answered single choice question.  # noqa: E501

        :return: The total_score_percentage of this GetInterviewDetailsForEvaluatingResponseData.  # noqa: E501
        :rtype: str
        """
        return self._total_score_percentage

    @total_score_percentage.setter
    def total_score_percentage(self, total_score_percentage):
        """Sets the total_score_percentage of this GetInterviewDetailsForEvaluatingResponseData.

        Percentage score candidate has scored when he answered single choice question.  # noqa: E501

        :param total_score_percentage: The total_score_percentage of this GetInterviewDetailsForEvaluatingResponseData.  # noqa: E501
        :type: str
        """
        if total_score_percentage is None:
            raise ValueError("Invalid value for `total_score_percentage`, must not be `None`")  # noqa: E501

        self._total_score_percentage = total_score_percentage

    @property
    def answered_score_points(self):
        """Gets the answered_score_points of this GetInterviewDetailsForEvaluatingResponseData.  # noqa: E501

        Score value for all single choice question answered.  # noqa: E501

        :return: The answered_score_points of this GetInterviewDetailsForEvaluatingResponseData.  # noqa: E501
        :rtype: float
        """
        return self._answered_score_points

    @answered_score_points.setter
    def answered_score_points(self, answered_score_points):
        """Sets the answered_score_points of this GetInterviewDetailsForEvaluatingResponseData.

        Score value for all single choice question answered.  # noqa: E501

        :param answered_score_points: The answered_score_points of this GetInterviewDetailsForEvaluatingResponseData.  # noqa: E501
        :type: float
        """
        if answered_score_points is None:
            raise ValueError("Invalid value for `answered_score_points`, must not be `None`")  # noqa: E501

        self._answered_score_points = answered_score_points

    @property
    def max_score_points(self):
        """Gets the max_score_points of this GetInterviewDetailsForEvaluatingResponseData.  # noqa: E501

        Max score points available for question.  # noqa: E501

        :return: The max_score_points of this GetInterviewDetailsForEvaluatingResponseData.  # noqa: E501
        :rtype: float
        """
        return self._max_score_points

    @max_score_points.setter
    def max_score_points(self, max_score_points):
        """Sets the max_score_points of this GetInterviewDetailsForEvaluatingResponseData.

        Max score points available for question.  # noqa: E501

        :param max_score_points: The max_score_points of this GetInterviewDetailsForEvaluatingResponseData.  # noqa: E501
        :type: float
        """
        if max_score_points is None:
            raise ValueError("Invalid value for `max_score_points`, must not be `None`")  # noqa: E501

        self._max_score_points = max_score_points

    @property
    def has_scored_question(self):
        """Gets the has_scored_question of this GetInterviewDetailsForEvaluatingResponseData.  # noqa: E501

        Has scored question can be true or false.  # noqa: E501

        :return: The has_scored_question of this GetInterviewDetailsForEvaluatingResponseData.  # noqa: E501
        :rtype: bool
        """
        return self._has_scored_question

    @has_scored_question.setter
    def has_scored_question(self, has_scored_question):
        """Sets the has_scored_question of this GetInterviewDetailsForEvaluatingResponseData.

        Has scored question can be true or false.  # noqa: E501

        :param has_scored_question: The has_scored_question of this GetInterviewDetailsForEvaluatingResponseData.  # noqa: E501
        :type: bool
        """
        if has_scored_question is None:
            raise ValueError("Invalid value for `has_scored_question`, must not be `None`")  # noqa: E501

        self._has_scored_question = has_scored_question

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetInterviewDetailsForEvaluatingResponseData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetInterviewDetailsForEvaluatingResponseData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    videoplatform-api

    Interview Screening APIs allows to invite candidate to interview, evaluate and review candidates interview performances.  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: support@phenompeople.com
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class GetAllEvaluationsForInterviewIdDataAnswerRatings(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'question_id': 'str',
        'question_text': 'str',
        'type': 'str',
        'answer_rating': 'float',
        'video_id': 'str',
        'answer_text': 'str',
        'selected_option_ids': 'list[str]',
        'mcs_question_id': 'str'
    }

    attribute_map = {
        'question_id': 'questionId',
        'question_text': 'questionText',
        'type': 'type',
        'answer_rating': 'answerRating',
        'video_id': 'videoId',
        'answer_text': 'answerText',
        'selected_option_ids': 'selectedOptionIds',
        'mcs_question_id': 'mcsQuestionId'
    }

    def __init__(self, question_id=None, question_text=None, type=None, answer_rating=None, video_id=None, answer_text=None, selected_option_ids=None, mcs_question_id=None):  # noqa: E501
        """GetAllEvaluationsForInterviewIdDataAnswerRatings - a model defined in Swagger"""  # noqa: E501
        self._question_id = None
        self._question_text = None
        self._type = None
        self._answer_rating = None
        self._video_id = None
        self._answer_text = None
        self._selected_option_ids = None
        self._mcs_question_id = None
        self.discriminator = None
        self.question_id = question_id
        self.question_text = question_text
        self.type = type
        self.answer_rating = answer_rating
        if video_id is not None:
            self.video_id = video_id
        if answer_text is not None:
            self.answer_text = answer_text
        if selected_option_ids is not None:
            self.selected_option_ids = selected_option_ids
        self.mcs_question_id = mcs_question_id

    @property
    def question_id(self):
        """Gets the question_id of this GetAllEvaluationsForInterviewIdDataAnswerRatings.  # noqa: E501

        This is the interview question id, not to be confused with actual question id.  # noqa: E501

        :return: The question_id of this GetAllEvaluationsForInterviewIdDataAnswerRatings.  # noqa: E501
        :rtype: str
        """
        return self._question_id

    @question_id.setter
    def question_id(self, question_id):
        """Sets the question_id of this GetAllEvaluationsForInterviewIdDataAnswerRatings.

        This is the interview question id, not to be confused with actual question id.  # noqa: E501

        :param question_id: The question_id of this GetAllEvaluationsForInterviewIdDataAnswerRatings.  # noqa: E501
        :type: str
        """
        if question_id is None:
            raise ValueError("Invalid value for `question_id`, must not be `None`")  # noqa: E501

        self._question_id = question_id

    @property
    def question_text(self):
        """Gets the question_text of this GetAllEvaluationsForInterviewIdDataAnswerRatings.  # noqa: E501

        Question text of question.  # noqa: E501

        :return: The question_text of this GetAllEvaluationsForInterviewIdDataAnswerRatings.  # noqa: E501
        :rtype: str
        """
        return self._question_text

    @question_text.setter
    def question_text(self, question_text):
        """Sets the question_text of this GetAllEvaluationsForInterviewIdDataAnswerRatings.

        Question text of question.  # noqa: E501

        :param question_text: The question_text of this GetAllEvaluationsForInterviewIdDataAnswerRatings.  # noqa: E501
        :type: str
        """
        if question_text is None:
            raise ValueError("Invalid value for `question_text`, must not be `None`")  # noqa: E501

        self._question_text = question_text

    @property
    def type(self):
        """Gets the type of this GetAllEvaluationsForInterviewIdDataAnswerRatings.  # noqa: E501

        Type of the question, could be video, audio, videoOrAudio, multiple, scored, single, knockout, text.  # noqa: E501

        :return: The type of this GetAllEvaluationsForInterviewIdDataAnswerRatings.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this GetAllEvaluationsForInterviewIdDataAnswerRatings.

        Type of the question, could be video, audio, videoOrAudio, multiple, scored, single, knockout, text.  # noqa: E501

        :param type: The type of this GetAllEvaluationsForInterviewIdDataAnswerRatings.  # noqa: E501
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    @property
    def answer_rating(self):
        """Gets the answer_rating of this GetAllEvaluationsForInterviewIdDataAnswerRatings.  # noqa: E501

        Rating give for the answered question.  # noqa: E501

        :return: The answer_rating of this GetAllEvaluationsForInterviewIdDataAnswerRatings.  # noqa: E501
        :rtype: float
        """
        return self._answer_rating

    @answer_rating.setter
    def answer_rating(self, answer_rating):
        """Sets the answer_rating of this GetAllEvaluationsForInterviewIdDataAnswerRatings.

        Rating give for the answered question.  # noqa: E501

        :param answer_rating: The answer_rating of this GetAllEvaluationsForInterviewIdDataAnswerRatings.  # noqa: E501
        :type: float
        """
        if answer_rating is None:
            raise ValueError("Invalid value for `answer_rating`, must not be `None`")  # noqa: E501

        self._answer_rating = answer_rating

    @property
    def video_id(self):
        """Gets the video_id of this GetAllEvaluationsForInterviewIdDataAnswerRatings.  # noqa: E501

        This field is applicable of audio or video question.  # noqa: E501

        :return: The video_id of this GetAllEvaluationsForInterviewIdDataAnswerRatings.  # noqa: E501
        :rtype: str
        """
        return self._video_id

    @video_id.setter
    def video_id(self, video_id):
        """Sets the video_id of this GetAllEvaluationsForInterviewIdDataAnswerRatings.

        This field is applicable of audio or video question.  # noqa: E501

        :param video_id: The video_id of this GetAllEvaluationsForInterviewIdDataAnswerRatings.  # noqa: E501
        :type: str
        """

        self._video_id = video_id

    @property
    def answer_text(self):
        """Gets the answer_text of this GetAllEvaluationsForInterviewIdDataAnswerRatings.  # noqa: E501

        This field is applicable for text question only. This contains the answer given by the candidate.  # noqa: E501

        :return: The answer_text of this GetAllEvaluationsForInterviewIdDataAnswerRatings.  # noqa: E501
        :rtype: str
        """
        return self._answer_text

    @answer_text.setter
    def answer_text(self, answer_text):
        """Sets the answer_text of this GetAllEvaluationsForInterviewIdDataAnswerRatings.

        This field is applicable for text question only. This contains the answer given by the candidate.  # noqa: E501

        :param answer_text: The answer_text of this GetAllEvaluationsForInterviewIdDataAnswerRatings.  # noqa: E501
        :type: str
        """

        self._answer_text = answer_text

    @property
    def selected_option_ids(self):
        """Gets the selected_option_ids of this GetAllEvaluationsForInterviewIdDataAnswerRatings.  # noqa: E501


        :return: The selected_option_ids of this GetAllEvaluationsForInterviewIdDataAnswerRatings.  # noqa: E501
        :rtype: list[str]
        """
        return self._selected_option_ids

    @selected_option_ids.setter
    def selected_option_ids(self, selected_option_ids):
        """Sets the selected_option_ids of this GetAllEvaluationsForInterviewIdDataAnswerRatings.


        :param selected_option_ids: The selected_option_ids of this GetAllEvaluationsForInterviewIdDataAnswerRatings.  # noqa: E501
        :type: list[str]
        """

        self._selected_option_ids = selected_option_ids

    @property
    def mcs_question_id(self):
        """Gets the mcs_question_id of this GetAllEvaluationsForInterviewIdDataAnswerRatings.  # noqa: E501

        This is the interview questionId.  # noqa: E501

        :return: The mcs_question_id of this GetAllEvaluationsForInterviewIdDataAnswerRatings.  # noqa: E501
        :rtype: str
        """
        return self._mcs_question_id

    @mcs_question_id.setter
    def mcs_question_id(self, mcs_question_id):
        """Sets the mcs_question_id of this GetAllEvaluationsForInterviewIdDataAnswerRatings.

        This is the interview questionId.  # noqa: E501

        :param mcs_question_id: The mcs_question_id of this GetAllEvaluationsForInterviewIdDataAnswerRatings.  # noqa: E501
        :type: str
        """
        if mcs_question_id is None:
            raise ValueError("Invalid value for `mcs_question_id`, must not be `None`")  # noqa: E501

        self._mcs_question_id = mcs_question_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetAllEvaluationsForInterviewIdDataAnswerRatings, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetAllEvaluationsForInterviewIdDataAnswerRatings):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    apply-api

    The Apply API allows for seamless integration of the Phenom systems, enabling partners to push applications directly. This API also enables partners to integrate the Phenom Quick application process into their own job boards, while still maintaining control over the candidate experience. As a result, candidates can submit their applications without needing to visit the customer career site.  # noqa: E501

    OpenAPI spec version: 2.0.0
    
    Generated by: phenom
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from phenom.commons.api_client import ApiClient


class AttachmentsApi(object):
    base_path = "/apply"  # your base path

    def __init__(self, token, gateway_url, apikey, api_client=None):
        if api_client is None:
            api_client = ApiClient(gateway_url + self.base_path, apikey, token)
        self.api_client = api_client

    def download_attachments(self, id, **kwargs):  # noqa: E501
        """Download Attachments  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.download_attachments(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: It is a 24-digit hexadecimal value that represents Application Id. (required)
        :return: GetAttachmentsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.download_attachments_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.download_attachments_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def download_attachments_with_http_info(self, id, **kwargs):  # noqa: E501
        """Download Attachments  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.download_attachments_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: It is a 24-digit hexadecimal value that represents Application Id. (required)
        :return: GetAttachmentsResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method download_attachments" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `download_attachments`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v2/applications/{id}/attachments', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='GetAttachmentsResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def upload_attachments(self, body, id, **kwargs):  # noqa: E501
        """Upload Attachments  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.upload_attachments(body, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[Resume] body: (required)
        :param str id: It is a 24-digit hexadecimal value that represents Application Id. (required)
        :return: UploadAttachmentResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.upload_attachments_with_http_info(body, id, **kwargs)  # noqa: E501
        else:
            (data) = self.upload_attachments_with_http_info(body, id, **kwargs)  # noqa: E501
            return data

    def upload_attachments_with_http_info(self, body, id, **kwargs):  # noqa: E501
        """Upload Attachments  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.upload_attachments_with_http_info(body, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[Resume] body: (required)
        :param str id: It is a 24-digit hexadecimal value that represents Application Id. (required)
        :return: UploadAttachmentResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method upload_attachments" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `upload_attachments`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `upload_attachments`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/v2/applications/{id}/attachments', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='UploadAttachmentResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    candidates-attachments-api

    The Candidate APIs allows you to add, update and delete candidate attachments.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class DeleteAttachmentRequestAttachments(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'attachment_type': 'str',
        'md5sum': 'str',
        'attachment_name': 'str',
        'field_id': 'str'
    }

    attribute_map = {
        'attachment_type': 'attachmentType',
        'md5sum': 'md5sum',
        'attachment_name': 'attachmentName',
        'field_id': 'fieldId'
    }

    def __init__(self, attachment_type=None, md5sum=None, attachment_name=None, field_id=None):  # noqa: E501
        """DeleteAttachmentRequestAttachments - a model defined in Swagger"""  # noqa: E501
        self._attachment_type = None
        self._md5sum = None
        self._attachment_name = None
        self._field_id = None
        self.discriminator = None
        self.attachment_type = attachment_type
        self.md5sum = md5sum
        self.attachment_name = attachment_name
        if field_id is not None:
            self.field_id = field_id

    @property
    def attachment_type(self):
        """Gets the attachment_type of this DeleteAttachmentRequestAttachments.  # noqa: E501

        The type of the attachment to be deleted.  # noqa: E501

        :return: The attachment_type of this DeleteAttachmentRequestAttachments.  # noqa: E501
        :rtype: str
        """
        return self._attachment_type

    @attachment_type.setter
    def attachment_type(self, attachment_type):
        """Sets the attachment_type of this DeleteAttachmentRequestAttachments.

        The type of the attachment to be deleted.  # noqa: E501

        :param attachment_type: The attachment_type of this DeleteAttachmentRequestAttachments.  # noqa: E501
        :type: str
        """
        if attachment_type is None:
            raise ValueError("Invalid value for `attachment_type`, must not be `None`")  # noqa: E501

        self._attachment_type = attachment_type

    @property
    def md5sum(self):
        """Gets the md5sum of this DeleteAttachmentRequestAttachments.  # noqa: E501

        The MD5 checksum of the attachment to be deleted.  # noqa: E501

        :return: The md5sum of this DeleteAttachmentRequestAttachments.  # noqa: E501
        :rtype: str
        """
        return self._md5sum

    @md5sum.setter
    def md5sum(self, md5sum):
        """Sets the md5sum of this DeleteAttachmentRequestAttachments.

        The MD5 checksum of the attachment to be deleted.  # noqa: E501

        :param md5sum: The md5sum of this DeleteAttachmentRequestAttachments.  # noqa: E501
        :type: str
        """
        if md5sum is None:
            raise ValueError("Invalid value for `md5sum`, must not be `None`")  # noqa: E501

        self._md5sum = md5sum

    @property
    def attachment_name(self):
        """Gets the attachment_name of this DeleteAttachmentRequestAttachments.  # noqa: E501

        The name of the attachment to be deleted.  # noqa: E501

        :return: The attachment_name of this DeleteAttachmentRequestAttachments.  # noqa: E501
        :rtype: str
        """
        return self._attachment_name

    @attachment_name.setter
    def attachment_name(self, attachment_name):
        """Sets the attachment_name of this DeleteAttachmentRequestAttachments.

        The name of the attachment to be deleted.  # noqa: E501

        :param attachment_name: The attachment_name of this DeleteAttachmentRequestAttachments.  # noqa: E501
        :type: str
        """
        if attachment_name is None:
            raise ValueError("Invalid value for `attachment_name`, must not be `None`")  # noqa: E501

        self._attachment_name = attachment_name

    @property
    def field_id(self):
        """Gets the field_id of this DeleteAttachmentRequestAttachments.  # noqa: E501

        The ID of the attachment field to be deleted.  # noqa: E501

        :return: The field_id of this DeleteAttachmentRequestAttachments.  # noqa: E501
        :rtype: str
        """
        return self._field_id

    @field_id.setter
    def field_id(self, field_id):
        """Sets the field_id of this DeleteAttachmentRequestAttachments.

        The ID of the attachment field to be deleted.  # noqa: E501

        :param field_id: The field_id of this DeleteAttachmentRequestAttachments.  # noqa: E501
        :type: str
        """

        self._field_id = field_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DeleteAttachmentRequestAttachments, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeleteAttachmentRequestAttachments):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    applicants-api

    This API collection enables seamless operations by facilitating the retrieval of essential applicant details, updating and managing hiring statuses for candidates, assigning multiple candidates as leads for specific job roles, and obtaining detailed activity logs associated with applicants.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: phenom
"""

import pprint
import re  # noqa: F401

import six

class NextHiringStatusDataTransitionStatuses(object):
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'status_code': 'str',
        'is_rejected': 'bool',
        'is_default': 'bool',
        'step': 'str'
    }

    attribute_map = {
        'name': 'name',
        'status_code': 'statusCode',
        'is_rejected': 'isRejected',
        'is_default': 'isDefault',
        'step': 'step'
    }

    def __init__(self, name=None, status_code=None, is_rejected=None, is_default=None, step=None):  # noqa: E501
        """NextHiringStatusDataTransitionStatuses - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._status_code = None
        self._is_rejected = None
        self._is_default = None
        self._step = None
        self.discriminator = None
        if name is not None:
            self.name = name
        if status_code is not None:
            self.status_code = status_code
        if is_rejected is not None:
            self.is_rejected = is_rejected
        if is_default is not None:
            self.is_default = is_default
        if step is not None:
            self.step = step

    @property
    def name(self):
        """Gets the name of this NextHiringStatusDataTransitionStatuses.  # noqa: E501

        Name of the transition status.  # noqa: E501

        :return: The name of this NextHiringStatusDataTransitionStatuses.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this NextHiringStatusDataTransitionStatuses.

        Name of the transition status.  # noqa: E501

        :param name: The name of this NextHiringStatusDataTransitionStatuses.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def status_code(self):
        """Gets the status_code of this NextHiringStatusDataTransitionStatuses.  # noqa: E501

        Status code of the transition status.  # noqa: E501

        :return: The status_code of this NextHiringStatusDataTransitionStatuses.  # noqa: E501
        :rtype: str
        """
        return self._status_code

    @status_code.setter
    def status_code(self, status_code):
        """Sets the status_code of this NextHiringStatusDataTransitionStatuses.

        Status code of the transition status.  # noqa: E501

        :param status_code: The status_code of this NextHiringStatusDataTransitionStatuses.  # noqa: E501
        :type: str
        """

        self._status_code = status_code

    @property
    def is_rejected(self):
        """Gets the is_rejected of this NextHiringStatusDataTransitionStatuses.  # noqa: E501

        Flag indicating whether the transition status is rejected.  # noqa: E501

        :return: The is_rejected of this NextHiringStatusDataTransitionStatuses.  # noqa: E501
        :rtype: bool
        """
        return self._is_rejected

    @is_rejected.setter
    def is_rejected(self, is_rejected):
        """Sets the is_rejected of this NextHiringStatusDataTransitionStatuses.

        Flag indicating whether the transition status is rejected.  # noqa: E501

        :param is_rejected: The is_rejected of this NextHiringStatusDataTransitionStatuses.  # noqa: E501
        :type: bool
        """

        self._is_rejected = is_rejected

    @property
    def is_default(self):
        """Gets the is_default of this NextHiringStatusDataTransitionStatuses.  # noqa: E501

        Flag indicating whether the transition status is the default.  # noqa: E501

        :return: The is_default of this NextHiringStatusDataTransitionStatuses.  # noqa: E501
        :rtype: bool
        """
        return self._is_default

    @is_default.setter
    def is_default(self, is_default):
        """Sets the is_default of this NextHiringStatusDataTransitionStatuses.

        Flag indicating whether the transition status is the default.  # noqa: E501

        :param is_default: The is_default of this NextHiringStatusDataTransitionStatuses.  # noqa: E501
        :type: bool
        """

        self._is_default = is_default

    @property
    def step(self):
        """Gets the step of this NextHiringStatusDataTransitionStatuses.  # noqa: E501

        Current step in the workflow for the transition status.  # noqa: E501

        :return: The step of this NextHiringStatusDataTransitionStatuses.  # noqa: E501
        :rtype: str
        """
        return self._step

    @step.setter
    def step(self, step):
        """Sets the step of this NextHiringStatusDataTransitionStatuses.

        Current step in the workflow for the transition status.  # noqa: E501

        :param step: The step of this NextHiringStatusDataTransitionStatuses.  # noqa: E501
        :type: str
        """

        self._step = step

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(NextHiringStatusDataTransitionStatuses, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NextHiringStatusDataTransitionStatuses):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
